nwbwidgets.controllers package
==============================

Submodules
----------

nwbwidgets.controllers.group\_and\_sort\_controllers module
-----------------------------------------------------------

.. automodule:: nwbwidgets.controllers.group_and_sort_controllers
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.controllers.misc module
----------------------------------

.. automodule:: nwbwidgets.controllers.misc
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.controllers.time\_window\_controllers module
-------------------------------------------------------

.. automodule:: nwbwidgets.controllers.time_window_controllers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nwbwidgets.controllers
   :members:
   :undoc-members:
   :show-inheritance:
